@@ -17,6 +17,7 @@ class Recurface:
         self.__rect_additional = []
 
         self.__child_recurfaces = set()
+        self.__frozen_child_recurfaces = frozenset()
         self.__ordered_child_recurfaces = tuple()
 
         self.__parent_recurface = None
@@ -114,7 +115,7 @@ class Recurface:
 
     @property
     def child_recurfaces(self) -> FrozenSet["Recurface"]:
-        return frozenset(self.__child_recurfaces)
+        return self.__frozen_child_recurfaces
 
     @property
     def ordered_child_recurfaces(self) -> Tuple["Recurface", ...]:
@@ -126,7 +127,7 @@ class Recurface:
         """
 
         if type(self.__ordered_child_recurfaces) is TypeError:
-            raise self.__ordered_child_recurfaces
+            raise TypeError("unable to sort child recurfaces by priority")
         else:
             return self.__ordered_child_recurfaces
 
@@ -139,14 +140,14 @@ class Recurface:
         self.__render_priority = value
 
         if self.parent_recurface:
-            self.parent_recurface._calculate_ordered_child_recurfaces()
+            self.parent_recurface._organise_child_recurfaces()
 
     def add_child_recurface(self, child: "Recurface") -> None:
         if child in self.__child_recurfaces:
             return  # Child is already added
 
         self.__child_recurfaces.add(child)
-        self._calculate_ordered_child_recurfaces()
+        self._organise_child_recurfaces()
 
         child.parent_recurface = self
 
@@ -155,7 +156,7 @@ class Recurface:
     def remove_child_recurface(self, child: "Recurface") -> None:
         if child in self.__child_recurfaces:
             self.__child_recurfaces.remove(child)
-            self._calculate_ordered_child_recurfaces()
+            self._organise_child_recurfaces()
 
             child.parent_recurface = None
 
@@ -196,13 +197,21 @@ class Recurface:
 
                 self.__rect_additional.append(rect)
 
-    def render(self, destination: Surface) -> List[Optional[Rect]]:
+    def render(self, destination: Surface) -> List[Rect]:
+        """
+        Wrapper method for `._render()`.
+        Returns an optimised list of pygame rects representing updated areas of the provided destination.
+
+        This method should typically be called on top-level (parent-less) recurfaces once per game tick,
+        and `pygame.display.update()` should be passed the returned list of rects
+        """
+
+        return self.trimmed_rects(self._render(destination))
+
+    def _render(self, destination: Surface) -> List[Optional[Rect]]:
         """
         Draws all child surfaces to a copy of .surface, then draws the copy to the provided destination.
         Returns a list of pygame rects representing updated areas of the provided destination.
-
-        Note: This function should be called on top-level (parent-less) recurfaces once per game tick, and
-        pygame.display.update() should be passed all returned rects
         """
 
         result = []
@@ -226,7 +235,7 @@ class Recurface:
 
         child_rects = []
         for child in child_recurfaces:  # Render all child objects in the correct order and collect returned Rects
-            rects = child.render(surface_working)
+            rects = child._render(surface_working)
 
             for rect in rects:
                 if rect:  # Update rect position to account for nesting
@@ -286,10 +295,49 @@ class Recurface:
         self.__rect_previous = None
         self.__rect_additional = []
 
-    def _calculate_ordered_child_recurfaces(self) -> None:
+    def _organise_child_recurfaces(self) -> None:
+        self.__frozen_child_recurfaces = frozenset(self.__child_recurfaces)
+
         try:
             self.__ordered_child_recurfaces = tuple(
                 sorted(self.__child_recurfaces, key=lambda recurface: recurface.render_priority)
             )
         except TypeError as ex:  # Unable to sort recurfaces due to non-comparable priority values
             self.__ordered_child_recurfaces = ex
+
+    @staticmethod
+    def trimmed_rects(rects: List[Optional[Rect]]) -> List[Rect]:
+        """
+        Optimisation method applied in `.render_to_display()`.
+
+        Trims any None objects from the provided list, and any Rect objects whose bounds are entirely contained
+        within another Rect object in the list
+        """
+
+        result = []
+
+        for rect_index, rect in enumerate(rects):
+            if rect is None:
+                continue
+
+            include_rect = True
+            for other_rect_index, other_rect in enumerate(rects):
+                if other_rect is None:
+                    continue
+
+                if other_rect_index == rect_index:
+                    continue
+
+                if is_rect_inside_other_rect := (
+                    (rect.left >= other_rect.left) and
+                    (rect.right <= other_rect.right) and
+                    (rect.top >= other_rect.top) and
+                    (rect.bottom >= other_rect.bottom)
+                ):
+                    include_rect = False
+                    break
+
+            if include_rect:
+                result.append(rect)
+
+        return result
